# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that defines the behavior of the
"Stations"
menu item in the popup menu.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gtk import ImageMenuItem

class StationsMenuItem(ImageMenuItem):
	"""
	This class defines the behavior of the "Stations" menu item.
	"""

	def __init__(self, player):
		"""
		Initialize object.

		@param self: Reference to the StationsMenuItem instance.
		@type self: A StationsMenuItem object.

		@param player: Reference to the Player Instance.
		@type player: A Player object.
		"""
		ImageMenuItem.__init__(self)
		self.__init_attributes(player)
		self.__set_properties()
		self.connect("activate", self.__activate_cb)

	def __init_attributes(self, player):
		"""
		Initialize data attributes.

		@param self: Reference to the StationsMenuItem instance.
		@type self: A StationsMenuItem object.

		@param player: Reference to the Player Instance.
		@type player: A Player object.
		"""
		self.__player = player
		from gtk import Label, Image
		self.__image = Image()
		from i18n import msg0005
		self.__label = Label(msg0005)
		return

	def __set_properties(self):
		"""
		Set default properties.

		@param self: Reference to the StationsMenuItem instance.
		@type self: A StationsMenuItem object.
		"""
		self.__label.set_use_underline(True)
		from Striim.Global import striim_data_folder
		image = striim_data_folder + "/striim.png"
		from Striim.utils import get_pixbuf_from_file
		pixbuf = get_pixbuf_from_file(image, (16, 16))
		self.__image.set_from_pixbuf(pixbuf)
		self.set_property("image", self.__image)
		from gtk import HBox
		hbox = HBox()
		self.add(hbox)
		hbox.pack_start(self.__label, False, False, 0)
		return

	def __activate_cb(self, *args):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the StationsMenuItem instance.
		@type self: A StationsMenuItem object.
		"""
		self.__player.trigger("show_stations_dialog")
		return True
