# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that defines the behavior of the increase
volume button.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

class VolumeUpButton(object):
	"""
	This class defines the behavior of the increase volume button.
	"""

	def __init__(self, manager, glade):
		"""
		Initialize object.

		@param self: Reference to the VolumeUpButton instance.
		@type self: A VolumeUpButton object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__init_attributes(manager, glade)
		self.__sig_id_1 = manager.connect("destroy", self.__destroy_cb)
		self.__sig_id_2 = manager.connect("volume", self.__volume_cb)
		self.__sig_id_3 = self.__button.connect("clicked", self.__clicked_cb)

	def __init_attributes(self, manager, glade):
		"""
		Initialize data attributes.

		@param self: Reference to the VolumeUpButton instance.
		@type self: A VolumeUpButton object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__manager = manager
		self.__button = glade.get_widget("VolumeUp")
		return

	def __destroy_cb(self, *args):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the VolumeUpButton instance.
		@type self: A VolumeUpButton object.
		"""
		from Striim.utils import disconnect_signal, delete_attributes
		disconnect_signal(self.__sig_id_1, self.__manager)
		disconnect_signal(self.__sig_id_2, self.__manager)
		disconnect_signal(self.__sig_id_3, self)
		delete_attributes(self)
		del self
		self = None
		return

	def __clicked_cb(self, *args):
		"""
		Handles callback when the "clicked" signal is emitted.

		@param self: Reference to the VolumeUpButton instance.
		@type self: A VolumeUpButton object.
		"""
		self.__manager.increase_volume()
		return

	def __volume_cb(self, manager, volume, data):
		"""
		Handles callback when the "volume" signal is emitted.

		@param self: Reference to the VolumeUpButton instance.
		@type self: A VolumeUpButton object.

		@param volume: New volume level.
		@type volume: A Float object.

		@param data: Not needed.
		@type data: A Boolean object.
		"""
		from operator import ge
		if ge(volume, 1.0):
			self.__button.set_property("sensitive", False)
		else:
			self.__button.set_property("sensitive", True)
		return
